.. meta::
   :description: Gaitalytics IO.
   :keywords: gaitalytics, gait-analysis, mocap, c3d, gait-metrics, biomechanics, time-series, data-analysis, data, gait, references

Input / Output
==============

.. warning::
    File types .sto, .trc, .csv are not tested yet.

.. automodule:: gaitalytics.io
    :members:
    :special-members: __init__
